# LlamaIndex Workflow

## 📝 Table of Contents

- [About](#about)
- [Getting Started](#getting_started)
- [Usage](#usage)
- [TODO](../TODO.md)
- [Contributing](../CONTRIBUTING.md)
- [Authors](#authors)
- [Acknowledgments](#acknowledgement)

## 🧐 About <a name = "about"></a>

This repo is a lightweight fork of LlamaIndex's workflow module, offering powerful event-driven orchestration without the full llama-index-core dependencies. I love the work that LlamaIndex has done with their workflow module, and I wanted a lightweight version that I could use in my own projects without the overhead of the full llama-index-core module.

## 🏁 Getting Started <a name = "getting_started"></a>

TBD

### Prerequisites

TBD

### Installing

We use uv as package manager for all python dependencies. To install uv, run the following command:

```bash
curl -LsSf https://astral.sh/uv/install.sh | sh
```

To install the dependencies, run the following command:

```bash
uv install
```

## 🔧 Running the tests <a name = "tests"></a>

Tests are written using pytest. To run the tests, run the following command:

```bash
uv run pytest
```

## 🎈 Usage <a name="usage"></a>

TBD

## ✍️ Authors <a name = "authors"></a>

- [@maltehedderich](https://github.com/maltehedderich) - Forked from LlamaIndex

The code is 100% based on the work of LlamaIndex, and I am grateful for their work. I am just providing a lightweight version of their workflow module.

## 🎉 Acknowledgements <a name = "acknowledgement"></a>

Huge thanks to all the amazing contributors to the LlamaIndex project. I am grateful for their work and the inspiration they provide to the community.

The following list of authors and maintainers is derived from the pyproject.toml file of the original llama-index-core project:

- Andrei Fajardo <andrei@runllama.ai>
- Haotian Zhang <ht@runllama.ai>
- Jerry Liu <jerry@llamaindex.ai>
- Logan Markewich <logan@llamaindex.ai>
- Simon Suo <simon@llamaindex.ai>
  Sourabh Desai <sourabh@llamaindex.ai>

I can not list all the contributors here, but you can find them on the [LlamaIndex GitHub page](https://github.com/run-llama/llama_index).
